@@ -61,9 +61,7 @@ class KSelectAction;
 class KToggleAction;
 class LoginView;
 class LogoutView;
-#ifdef DEBUG
 class NetworkWindow;
-#endif
 class NateonDPLConnection;
 class NateonDPConnection;
 class Account;
@@ -72,6 +70,7 @@ class KNateonMainview;
 class ChatView;
 class MemoPopupView;
 class ChatList;
+class CurrentAccount;
 class SystemTrayWidget;
 class MemoView;
 class MemoList;
@@ -141,7 +140,6 @@ class KNateon : public KNateonInterface, virtual KNateOnDCOP
 	void dcopCommand( const QString s );
 	void saveUserDB();
 	void setDefaultWebBrowser();
-	void reqAddFriend(QString sID, QString sInviteMsg, bool bShowMsgBox = true);
   
 protected:
 	KActionMenu     *connectActionMenu_;
@@ -163,9 +161,7 @@ private:
 	KNateonMainview*      m_pMainView;
 	NateonDPLConnection*  m_pDPLcon;
 	NateonDPConnection*   m_pDPcon;
-#ifdef DEBUG
 	NetworkWindow*        m_pNetworkWindow;
-#endif
 	CurrentAccount*       m_pCurrentAccount;
     /// 대화창 관리.
 	ChatList*             m_pChatList;
@@ -216,7 +212,6 @@ private:
 	QTimer*                 m_pMemoPopupTimer;
 	QTimer*                 m_pC1C2Timer;
 	QTimer*	m_pRetryConnectTimer;
-	WebCGI*			pAuthTicketCGI;
 	WebCGI*                 pMemoCountCGI;
 	WebCGI*                 pMemoGetCGI;
 	WebCGI*                 pProfileGetCGI;
@@ -292,7 +287,6 @@ public slots:
 private slots:
 	void connectWithAccount ( Account *pAccount );
 	void connectDPWithAccount ( Account* pAccount );
-	void slotConnectDPWithAuthTicket( QStringList &slResult );
     // void DPLconnected();
 	void DPLdisconnected();
 	void connected();
@@ -314,8 +308,7 @@ private slots:
 	void slotGotAddGroup ( const QStringList& slCommand );
     /* void slotViewChat(QListViewItem* m_pSelectQLVI, const QPoint& m_cPointQP, int m_nID); */
 	void slotAddFriend();
-	void slotAddFriendRequire ( AddFriendView* pAddFriendView );
-	void slotNotFound( const QString &sTID );
+	void slotAddFiendRequire ( AddFriendView* pAddFriendView );
 	void gotINVT ( const QStringList& slCommand );
 	void slotSendINVT ( ChatView *pChatView );
 	void slotNewConnectSS( ChatView *pChatView );
@@ -329,7 +322,6 @@ private slots:
 	void slotErr309();
 	void slotErr421();
 	void slotErr500( const QStringList & );
-	void slotErr998( const QStringList & );
 	void slotDisconnected();
 	void slotLSIN();
 	void slotDPLError421();
@@ -425,8 +417,6 @@ private slots:
 	void slotCopyBuddy( const QString & sGroup );
 	void slotMoveBuddy( const QString & sGroup );
 	void slotDeleteBuddy();
-	void slotLoadBuddyList();
-	void slotSaveBuddyList();
   
 	/*! 버디 블럭 */
 	void slotBlockBuddy();
@@ -512,7 +502,7 @@ private slots:
 	/*! 다른 사용자로 로그인 */
 	void slotOtherLogin();
 
-	/*! 네이트 연동 해제 */
+	/*! 네이트닷컴 연동 해제 */
 	void slotNateSyncCancel();
 
 	/*! 프로필 보기 */
