@@ -82,11 +82,6 @@ nSelectGroup(0)
 	connect( listView3, SIGNAL( clicked ( QListViewItem * ) ), SLOT( slotBuddyListClicked( QListViewItem * ) ) );
 	connect( listView3, SIGNAL(clickedHompy(QListViewItem*)), this,
 		SLOT(slotGotoMinihompy(QListViewItem*)) );
-
-	/*!
-	 * added by luciferX2@gmail.com, 20081103 for Search
-	 */
-	//bSearchMode = FALSE;
 }
 
 
@@ -171,11 +166,7 @@ bool KNateonMainview::initialize()
 	  setView2(0);
 	*/
 
-	/*!
-	 * added and modified by luciferX2@gmail.com 20081103, for search
-	 */
-	connect( m_pSearchReset, SIGNAL( clicked() ), SLOT( slotResetBuddyList() ) );
-	connect( lineEdit1, SIGNAL( searchEnd() ), SLOT( slotResetBuddyList() ) );
+	connect( lineEdit1, SIGNAL( searchEnd() ), SLOT( slotSortNormal() ) );
 	connect( PB_FreeSMS, SIGNAL( clicked() ), SLOT( slotFreeSMS() ) );
 	
 	/// 단축키 설정.
@@ -287,9 +278,9 @@ void KNateonMainview::slotRightClickMenu(QListViewItem* item,const QPoint& point
 		else
 		{
 			/*!
-			 * 버디 이름과 이메일 주소를 오른쪽 팝업의 타이틀로 함.
+			 * 버디 이메일 주소를 오른쪽 팝업의 타이틀로 함.
 			 */
-			pBuddyRightClickMenu->changeTitle(0, pBuddy->getName() + " (" + pBuddy->getUID() + ")");
+			pBuddyRightClickMenu->changeTitle(0, pBuddy->getUID() );
 			pBuddyRightClickMenu->popup(point);
 
 			pBlockbuddyAction->setEnabled( TRUE );
@@ -1342,17 +1333,10 @@ void KNateonMainview::sortGroupName(bool bOnlyOnline)
 		//pGroupList->addGroup( pGroup );
 		etcGrpName = UTF8("ETC");
 		pGroup = pGroupList->getGroupByName( etcGrpName );
-		if ( !pGroup ) {
-		    pGroup = pGroupList->getGroupByID("0");
-		    if (!pGroup) {
-		        pGroup = new Group( "0", UTF8("기타") );
-		        pGroupList->addGroup( pGroup );
-            }
-        }
 	}
 
 #ifdef NETDEBUG
-	// kdDebug() << etcGrpName << " 의 아이템 수 : [" << pGroup->getBuddyList().count() << "]" << endl;
+	kdDebug() << etcGrpName << " 의 아이템 수 : [" << pGroup->getBuddyList().count() << "]" << endl;
 #endif
 		
 	ContactRoot* pRoot = new ContactRoot(listView3, pGroup->getGName(), pGroup->getGID() );
@@ -1790,14 +1774,6 @@ void KNateonMainview::slotListSearch(const QString & sKeyword)
 	QStringList slHan;
 	QStringList slBuddyList;
 
-	if ( sKeyword.length() )
-	{
-		m_pSearchReset->show();
-	}
-	else {
-		m_pSearchReset->hide();
-	}
-
 	/*! 버디 정렬을 위한 임시 리스트 변수 */
 	QPtrList<Buddy> myBuddy;
 	myBuddy.clear();
@@ -1820,27 +1796,21 @@ void KNateonMainview::slotListSearch(const QString & sKeyword)
 		pGroup = new Group( "0", UTF8("기타") );
 		pGroupList->addGroup( pGroup );
 	}
-
+	
 	QPtrListIterator<Buddy> iterBL( pGroup->getBuddyList() );
 	while( iterBL.current() != 0 )
 	{
 		pBuddy = iterBL.current();
-
 		if ( pBuddy )
 		{
-			if ( pBuddy->isFL() == false ) { 
-				++iterBL;
-				continue;
-			}
-
-/// 검색
+			if ( pBuddy->isFL() == false ) { continue; }
+			
+			/// 검색
 			if ( ( pBuddy->getName().find( sKeyword ) == -1 ) &&
-						    ( pBuddy->getNick().find( sKeyword ) == -1 ) ){
-				++iterBL;
+				 ( pBuddy->getNick().find( sKeyword ) == -1 ) )
 				continue;
-						    }
-						    myBuddy.append( pBuddy );
 
+			myBuddy.append( pBuddy );
 		}
 #ifdef NETDEBUG
 		else
@@ -1857,7 +1827,7 @@ void KNateonMainview::slotListSearch(const QString & sKeyword)
 		pRoot->setPixmap( folderOpen );
 		pRoot->setOpen(true);
 
-		MyBuddyList bList( myBuddy );
+		MyBuddyList  bList( myBuddy );
 		bList.sort();
 		QPtrListIterator<Buddy> itorBuddy( bList );
 
@@ -1865,7 +1835,7 @@ void KNateonMainview::slotListSearch(const QString & sKeyword)
 		while (itorBuddy.current() != 0)
 		{
 			pBuddy = itorBuddy.current();
-// pBuddy->setGID( pGroup->getGID() );
+			// pBuddy->setGID( pGroup->getGID() );
 
 			QListViewItem* pGroupItem = 0;
 			pGroupItem = listView3->findItem(pGroup->getGID(), 1, Qt::CaseSensitive);
@@ -1906,26 +1876,21 @@ void KNateonMainview::slotListSearch(const QString & sKeyword)
 				pGroup = pGroupList->getGroupByName( aa );
 				if ( !pGroup )
 					continue;
-				QPtrListIterator<Buddy> iterBL( pGroup->getBuddyList() );
-				while( iterBL.current() != 0 )
+        QPtrListIterator<Buddy> iterBL( pGroup->getBuddyList() );
+        while( iterBL.current() != 0 )
 				{
 					pBuddy = iterBL.current();
 					if ( pBuddy )
 					{
 						/*! FL(Friend List) == 0 */
-						if ( pBuddy->isFL() == false ) { 
-							++iterBL;
-							continue;
-						}
-
-/// 검색
+						if ( pBuddy->isFL() == false ) { continue; }
+						
+						/// 검색
 						if ( ( pBuddy->getName().find( sKeyword ) == -1 ) &&
-										( pBuddy->getNick().find( sKeyword ) == -1 ) ){
-							++iterBL;
+							 ( pBuddy->getNick().find( sKeyword ) == -1 ) )
 							continue;
-										}
 
-										myBuddy.append( pBuddy );
+						myBuddy.append( pBuddy );
 					}
 #ifdef NETDEBUG
 					else
@@ -1933,7 +1898,7 @@ void KNateonMainview::slotListSearch(const QString & sKeyword)
 						kdDebug() << "666> Nothing handle value : " << *iterBL << endl;
 					}
 #endif
-					++iterBL;
+          ++iterBL;
 				}
 				if ( myBuddy.count() > 0 )
 				{
@@ -1941,13 +1906,13 @@ void KNateonMainview::slotListSearch(const QString & sKeyword)
 					pRoot->setPixmap( folderOpen );
 					pRoot->setOpen(true);
 
-					MyBuddyList bList( myBuddy );
+					MyBuddyList  bList( myBuddy );
 					bList.sort();
 					QPtrListIterator<Buddy> itorBuddy( bList );
 					while (itorBuddy.current() != 0)
 					{
 						pBuddy = itorBuddy.current();
-// pBuddy->setGID( pGroup->getGID() );
+						// pBuddy->setGID( pGroup->getGID() );
 
 						QListViewItem* pGroupItem = 0;
 						pGroupItem = listView3->findItem(pGroup->getGID(), 1, Qt::CaseSensitive);
@@ -1992,26 +1957,21 @@ void KNateonMainview::slotListSearch(const QString & sKeyword)
 			{
 				pGroup = pGroupList->getGroupByName( *it );
 
-				QPtrListIterator<Buddy> iterBL( pGroup->getBuddyList() );
-				while( iterBL.current() != 0 )
+        QPtrListIterator<Buddy> iterBL( pGroup->getBuddyList() );
+        while( iterBL.current() != 0 )
 				{
 					pBuddy = iterBL.current();
 					if ( pBuddy )
 					{
 						/*! FL(Friend List) == 0 */
-						if ( pBuddy->isFL() == false ) {
-							++iterBL;
-							continue; 
-						}
-
-/// 검색
+						if ( pBuddy->isFL() == false ) { continue; }
+						
+						/// 검색
 						if ( ( pBuddy->getName().find( sKeyword ) == -1 ) &&
-										( pBuddy->getNick().find( sKeyword ) == -1 ) ){
-							++iterBL;
+							 ( pBuddy->getNick().find( sKeyword ) == -1 ) )
 							continue;
-										}
 
-										myBuddy.append( pBuddy );
+						myBuddy.append( pBuddy );
 					}
 #ifdef NETDEBUG
 					else
@@ -2019,7 +1979,7 @@ void KNateonMainview::slotListSearch(const QString & sKeyword)
 						kdDebug() << "777> Nothing handle value : " << *it << endl;
 					}
 #endif
-					++iterBL;
+          ++iterBL;
 				}
 
 				if ( myBuddy.count() > 0 )
@@ -2028,7 +1988,7 @@ void KNateonMainview::slotListSearch(const QString & sKeyword)
 					pRoot->setPixmap( folderOpen );
 					pRoot->setOpen(true);
 
-					MyBuddyList bList( myBuddy );
+					MyBuddyList  bList( myBuddy );
 					bList.sort();
 					QPtrListIterator<Buddy> itorBuddy( bList );
 					while (itorBuddy.current() != 0)
@@ -2104,36 +2064,8 @@ void KNateonMainview::slotListNameNick()
 	slotEmoticonList( stConfig.viewemoticonlist );
 }
 
-/*!
- * added by luciferX2@gmail.com 20081103, for search
- */
-void KNateonMainview::slotResetBuddyList()
-{
-	int nSort = stConfig.typeofbuddysort;
-
-	lineEdit1->setText( UTF8("친구 검색하기") );
-	lineEdit1->clearFocus();
-	m_pSearchReset->hide();
-
-	switch (nSort) {
-		case 0:
-			slotSortNormal();
-			break;
-		case 1:
-			slotSortOnlyOnline();
-			break;
-		case 2:
-			slotSortOnOffline();
-			break;
-	}
-}
-
 void KNateonMainview::slotSortNormal()
 {
-	/*!
-	 * added by luciferX2@gmail.com 20081103, for search
-	 */
-	//if (bSearchMode) return;
 	/*!
 	  수정해야 함. 디폴트 정렬.
 	*/
@@ -2147,10 +2079,6 @@ void KNateonMainview::slotSortNormal()
 
 void KNateonMainview::slotSortOnlyOnline()
 {
-	/*!
-	 * added by luciferX2@gmail.com 20081103, for search
-	 */
-	//if (bSearchMode) return;
 	/*!
 	  수정해야 함. 디폴트 정렬.
 	*/
@@ -2164,10 +2092,6 @@ void KNateonMainview::slotSortOnlyOnline()
 
 void KNateonMainview::slotSortOnOffline()
 {
-	/*!
-	 * added by luciferX2@gmail.com 20081103, for search
-	 */
-	//if (bSearchMode) return;
 	sortOnOffline();
 	stConfig.typeofbuddysort = 2;
 
@@ -2178,11 +2102,6 @@ void KNateonMainview::slotSortOnOffline()
 
 void KNateonMainview::slotEmoticonList(bool bEmoticon)
 {
-	/*!
-	 * added by luciferX2@gmail.com 20081103, for search
-	 */
-	//if (bSearchMode) return;
-	
 	stConfig.viewemoticonlist = bEmoticon;
 	switch ( stConfig.typeofbuddysort )
 	{
@@ -2597,4 +2516,3 @@ void KNateonMainview::groupOpenClose(QListViewItem * m_pSelectQLVI)
   }
   config->sync();
 }
-
