@@ -18,7 +18,6 @@
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 
-#include <stdlib.h>
 #include <kextsock.h>
 #include <kdebug.h>
 #include <klocale.h>
@@ -444,8 +443,7 @@ void NateonConnection::dataReceived()
 			}
 			delete ckInt;
 			// Check if this is a BODY-LEN + BODY protocol type :(
-			// CMSG : 클라이언트의 쪽지(Client MSG), PMSG : 웹쪽지(Push MSG), SMSG : 서버쪽지(Server MSG)
-			if ( slCommand[0] == "CONF" || slCommand[0] == "CTOC" || slCommand[0] == "CMSG" || slCommand[0] == "PMSG" || slCommand[0] == "SMSG" )
+			if ( slCommand[0] == "CONF" || slCommand[0] == "CTOC" )
 			{
 				// Get message length (last parameter)
 				nMessageLength   = slCommand[ slCommand.count() - 1 ].toInt();
@@ -457,11 +455,11 @@ void NateonConnection::dataReceived()
 				{
 					// Remove the command from the buffer
 					m_Buffer.remove( nIndex + 2 );
-#ifdef DEBUG
+
 					// Full message: send to network window
 					/*! 로그가 깨지는데 왜그럴까? */
 					emit messageReceived( sCommandLine.append("\n").append(  m_Buffer.left(nMessageLength) ) );
-#endif
+
 					// Get the message from the buffer and create the mime message
 					// Note we can't parse Strings here, the message could contain binary p2p data.
 					// Unicode characters are translated in the MimeMessage constructor itself.
@@ -470,7 +468,7 @@ void NateonConnection::dataReceived()
 
 					QString sTemp( m_Buffer.left(4) );
 
-					/// CMSG(or CTOC)에서 쪽지는 IMSG, 대화는 INVT 임. 분기가 필요해서 m_Buffer.left(4) 인자를 둠.
+					/// CTOC에서 쪽지는 IMSG, 대화는 INVT 임. 분기가 필요해서 m_Buffer.left(4) 인자를 둠.
 					if ( sTemp == "IMSG" )
 					{
 						parseMessage( m_Buffer.left(4), slCommand, mimeMessage );
@@ -481,7 +479,7 @@ void NateonConnection::dataReceived()
 						sBody = QString(m_Buffer.left( nMessageLength ));
 						parseBuffer(slCommand, sBody);
 					} else {
-						parseMessage( sTemp /* m_Buffer.left(4) */, slCommand, mimeMessage );
+						parseMessage( m_Buffer.left(4), slCommand, mimeMessage );
 					}
 					// delete from the buffer
 					m_Buffer.remove( nMessageLength );
@@ -503,11 +501,11 @@ void NateonConnection::dataReceived()
 #endif
 				// Remove the command from the buffer.
 				m_Buffer.remove( nIndex + 2 );
-#ifdef DEBUG
+
 				// Emit message for network window
 				emit messageReceived(QString::fromUtf8(sCommandLine));
 				// emit messageReceived( sCommandLine );
-#endif
+
 				// We parse ping responses internally
 				if ( slCommand[0] == "PONG" && m_bSendPings )
 				{
@@ -1350,7 +1348,7 @@ void NateonConnection::writeData(const QString& sData)
     if ( isConnected() )
     {
 	    QCString unicode;
-	    if ( m_pCurrentAccount->getProxyType() == Account::TYPE_HTTP /* 2 */) {
+	    if ( m_pCurrentAccount->getProxyType() == 2 ) {
 		    /*! HTTP Proxy */
 		    QString sHttp( m_pHttpProxy->getPOST( sData ) );
 		    unicode = sHttp.utf8();
@@ -1361,9 +1359,8 @@ void NateonConnection::writeData(const QString& sData)
     }
     // Unlock the writing of data.
     m_bWriteLocked = false;
-#ifdef DEBUG
+
     emit messageSent( QString::fromUtf8(sData) );
-#endif
 }
 
 
@@ -1414,9 +1411,7 @@ void NateonConnection::writeBinaryData(const QByteArray& data)
 #endif
     // Unlock the writing of data.
     m_bWriteLocked = false;
-#ifdef DEBUG
     emit messageSent(QString(data));
-#endif
 }
 
 
