@@ -18,11 +18,9 @@
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 
-#include <stdlib.h>
 #include "knateoncommon.h"
 #include "nateondpconnection.h"
 #include "util/common.h"
-#include "../shared/version.h"
 
 extern nmconfig stConfig;
 
@@ -105,171 +103,80 @@ bool NateonDPConnection::parseCommand(const QStringList& slCommand)
 
 	if (  slCommand[0] == "RCON" ) {
 		putLSIN();
-	}
-	else if ( slCommand[0] == "LSIN" ){
+	} else if ( slCommand[0] == "LSIN" ){
 		gotLSIN( slCommand );
-	}
-	else if ( slCommand[0] == "GLST") {
+	} else if ( slCommand[0] == "GLST") {
 		gotGLST( slCommand );
-	}
-	else if ( slCommand[0] == "LIST") {
+	} else if ( slCommand[0] == "LIST") {
 		gotLIST( slCommand );
-	}
-	else if ( slCommand[0] == "PING" ) {
+	} else if ( slCommand[0] == "PING" ) {
 		gotPING( slCommand );
-	}
-	else if ( slCommand[0] == "PACK" ) {
+	} else if ( slCommand[0] == "PACK" ) {
 		gotPACK( slCommand, slCommand[1]);
-	}
-	else if ( slCommand[0] == "RESS" ) {
+	} else if ( slCommand[0] == "RESS" ) {
 		gotRESS( slCommand );
-	}
-	else if ( (slCommand[0] == "INFY") || (slCommand[0] == "NTFY") ) {
+	} else if ( (slCommand[0] == "INFY") || (slCommand[0] == "NTFY") ) {
 		gotINFY( slCommand );
-	}
-	else if ( slCommand[0] == "ADDG" ) {
+	} else if ( slCommand[0] == "ADDG" ) {
 		gotADDG( slCommand );
-	}
-	else if ( slCommand[0] == "RMVG" ) {
+	} else if ( slCommand[0] == "RMVG" ) {
 		gotRMVG( slCommand );
-	}
-	else if ( slCommand[0] == "RENG" ) {
+	} else if ( slCommand[0] == "RENG" ) {
 		gotRENG( slCommand );
-	}
-	else if ( slCommand[0] == "ADSB" ) {
+	} else if ( slCommand[0] == "ADSB" ) {
 		gotADSB( slCommand );
-	}
-	else if ( slCommand[0] == "ADDB" ) {
+	} else if ( slCommand[0] == "ADDB" ) {
 		gotADDB( slCommand );
-	}
-	else if ( slCommand[0] == "200" ) {
+	} else if ( slCommand[0] == "200" ) {
 		emit err200();
-	}
-	else if ( slCommand[0] == "201" ) {
+	} else if ( slCommand[0] == "201" ) {
 		emit err201();
-	}
-	else if ( slCommand[0] == "202" ) {
+	} else if ( slCommand[0] == "202" ) {
 		emit err202();
-	}
-	else if ( slCommand[0] == "300" ) {
-		/*!
-		 * _T("존재하지 않는 아이디입니다. 확인후 다시 시도해 주십시오.\r\n\r\n추가 정보가 필요하시면 \"자세히\" 버튼을 눌러 주세요.")
-		 */
+	} else if ( slCommand[0] == "300" ) {
 		emit err300();
-	}
-	else if ( slCommand[0] == "301" ) {
-		/*!
-		 * _T("비밀번호가 틀렸습니다. 확인후 다시 시도해 주십시오.\r\n\r\n추가 정보가 필요하시면 \"자세히\" 버튼을 눌러 주세요.")
-		 */
+	} else if ( slCommand[0] == "301" ) { /*! 인증 에러, 로그인 / 싸이연동 에러 */
 		emit err301( slCommand );
-	}
-	else if ( slCommand[0] == "302" ) {
+	} else if ( slCommand[0] == "302" ) {
 		emit err302();
-	}
-	else if ( slCommand[0] == "304" ) {
-		/*!
-		 * 아이디를 찾을 수 없습니다.
-		 */
+	} else if ( slCommand[0] == "304" ) { /*! 아이디를 찾을 수 없습니다. */
 		Buddy* pBuddy = m_pBuddyList->getBuddyByHandle( slCommand[1] );
 		if (pBuddy) {
 			pBuddy->setUID("XXX");
 		}
-		emit err304( slCommand[1] );
-	}
-	else if ( slCommand[0] == "306" ) {
-		/*!
-		 * invalid sesssion 세션이 잘못되어있음.
-		 */
+		emit err304();
+	} else if ( slCommand[0] == "306" ) { /*! invalid sesssion 세션이 잘못되어있음.  */
 		emit err306();
-	}
-	else if ( slCommand[0] == "309" ) {
-		/*!
-		 * #define NATE_CODE_COMM_STOP           "309"   // Communication Stop 
-		 */
+	} else if ( slCommand[0] == "309" ) { /*! #define NATE_CODE_COMM_STOP           "309"   // Communication Stop */
 		emit err309();
-	}
-	else if ( slCommand[0] == "418" ) {
-		/*!
-		 * _T("현재 지원되지 않는 버전으로 로그인 시도를\n하였습니다.\n로그인을 하기 위해서는 업그레이드를 해야합니다.\n네이트온을 재실행하면 자동으로\n업그레이드가 됩니다.\n")
-		 */
-	}
-	else if ( slCommand[0] == "420" ) {
-		/*!
-		 * _T("현재 지원되지 않는 버전으로 로그인 시도를\n하였습니다.\n로그인을 하기 위해서는 업그레이드를 해야합니다.\n")
-		 */
-	}
-	else if ( slCommand[0] == "421" ) {
-		/*!
-		 * cannot connect back-end server error mr, css, cfr, ipml등에 연결할 수 없을 때.
-		 */
+	} else if ( slCommand[0] == "421" ) {/*! cannot connect back-end server error mr, css, cfr, ipml등에 연결할 수 없을 때. */
 		emit err421();
 	}
-	else if ( slCommand[0] == "500" ) {
-		/*!
-		 * #define NATE_CODE_DB_ERROR "500" // general db error
-		 */
+	else if ( slCommand[0] == "500" ) { /*! #define NATE_CODE_DB_ERROR "500" // general db error */
 		emit err500( slCommand );
 	}
-	else if ( slCommand[0] == "977" ) {
-		/*!
-		 * 997 TRID ErrCode ErrorMsg
-		 * 윈도우즈 네이트온에서는 로그인 실패창이 뜨고 자세히를 누르면 ErrorMsg가 노출
-		 * 로그인 실패창의 내용은 ErrCode에 따라 뿌려줌.( ex. 300/301/418/309)
-		 */
-	}
-	else if ( slCommand[0] == "998" ) {
-		/*!
-		 * 998 : 브라우져를 띄워줌
-		 * 998 [TRID] [BrCode] [BrParam] [TOOLBAR_YN] [Width] [Height]
-		 * Brcode에 해당하는 페이지로 BrParam을 파라미터로 브라우져를 실행
-		 * TOOLBAR_YN : Y(전체창) N(팝업)
-		 * Width, Height : 팝업일 경우 팝업 사이즈 
-		 */
-		emit err998( slCommand );
-	}
 	else if ( slCommand[0] == "REFR" ) {
 		emit receivedREFR( slCommand );
 	}
-	else if ( slCommand[0] == "CPRF" ) {
-		/*!
-		 * 싸이연동 변경 결과 
-		 */
+	else if ( slCommand[0] == "CPRF" ) { /*! 싸이연동 변경 결과 */
 		emit receivedCPRF( slCommand );
-	} else if ( slCommand[0] == "NNIK" ) {
-		/*!
-		 * 버디 닉 변경 
-		 */
+	} else if ( slCommand[0] == "NNIK" ) { /*! 버디 닉 변경 */
 		emit receivedNNIK( slCommand );
-	} else if ( slCommand[0] == "NPRF" ) {
-		/*!
-		 * 싸이연동 버디의 변경 내용
-		 */
+	} else if ( slCommand[0] == "NPRF" ) { /*! 싸이연동 버디의 변경 내용 */
 		emit receivedNPRF( slCommand );
-	} else if ( slCommand[0] == "TICK" ) {
-		/*!
-		 * 싸이연동 티켓값 받기
-		 */
+	} else if ( slCommand[0] == "TICK" ) { /*! 싸이연동 티켓값 받기 */
 		m_pCurrentAccount->setMyTicket( slCommand[2] );
-	} else if ( slCommand[0] == "KILL" ) {
-		/*!
-		 * 다른사용자 로그인 해서 끊김.
-		 */
+	} else if ( slCommand[0] == "KILL" ) { /*! 다른사용자 로그인 해서 끊김. */
 		emit kill();
-	} else if ( slCommand[0] == "ALRM" ) {
-		/*!
-		 * 알람패킷을 받았을때
-		 */
+	} else if ( slCommand[0] == "ALRM" ) { /*! 알람패킷을 받았을때 */
 		emit receivedALRM( slCommand );
-	} else if ( slCommand[0] == "CALM" ) {
-		/*!
-		 * 버디에 알람패킷을 받았을때
-		 */
+	} else if ( slCommand[0] == "CALM" ) { /*! 버디에 알람패킷을 받았을때 */
 		emit receivedCALM( slCommand );
 	} else if ( slCommand[0] == "RMVB" ) {
 		/*!
-		 * 서버에서 보내는 것은 TID가 0으로 넘어옴.
-		 * 본인이 코멘드를 날리고 리턴으로 받는 메시지는 TID가 0이 아님.
-		 */
+	 	* 서버에서 보내는 것은 TID가 0으로 넘어옴.
+	 	* 본인이 코멘드를 날리고 리턴으로 받는 메시지는 TID가 0이 아님.
+	 	*/
 		if ( slCommand[1] == "0" ) {
 			Buddy *pBuddy = m_pBuddyList->getBuddyByID( slCommand[4] );
 			if ( pBuddy ) {
@@ -294,8 +201,7 @@ bool NateonDPConnection::parseMessage(const QString &sCommand, const QStringList
 	{
 		gotCONF( slCommand );
 	}
-	// CMSG : 클라이언트의 쪽지(Client MSG), PMSG : 웹쪽지(Push MSG), SMSG : 서버쪽지(Server MSG)
-	else if ( slCommand[0] == "CTOC" || slCommand[0] == "CMSG" || slCommand[0] == "PMSG" || slCommand[0] == "SMSG" )
+	else if ( slCommand[0] == "CTOC")
 	{
 		if ( sCommand == "IMSG" ) {
 			// gotMemoCTOC( message );
@@ -347,75 +253,20 @@ void NateonDPConnection::connectionSuccess()
 /*!
   \fn NateonDPConnection::putLSIN()
 */
-#include <errno.h>
-#include <qfile.h>
-
-#define MAXLINE 256
-
 void NateonDPConnection::putLSIN()
 {
-	using namespace AutoVersion;
-	QString ticket;
-	QString cmd;
-	cmd.sprintf( "SSL %d.%d.%d.%d UTF8 ko.linux\r\n", \
-		MAJOR, MINOR, BUILD, REVISION );
-	sendCommand( "LSIN", m_pCurrentAccount->getID() + " " + m_pCurrentAccount->getAuthTicket() + " " + cmd );
-
-#if 0
 	QString sID = m_pCurrentAccount->getID();
 	QString sOrgPasswd = m_pCurrentAccount->getPassword();
-	QString sCommand;
-	QString filename;
-	if ( !QFile::exists( "/bin/nateongen" ) && !QFile::exists( "/usr/bin/nateongen" ) && !QFile::exists( "/usr/local/bin/nateongen" ) && !QFile::exists( "/opt/kde/bin/nateongen" ))
-	{
-		KMessageBox::error( 0, "Not Found 'nateongen', check file : /bin/nateongen or /usr/bin/nateongen or /usr/local/bin/nateongen or /opt/kde/bin/nateongen" );
-		exit(0);
-	}
-	
-	sCommand = "nateongen";
-	sCommand += " ";
-	sCommand += sID;
-	sCommand += " ";
-	sCommand += sOrgPasswd;
 
-	FILE *fp;
-	
-	char buff[MAXLINE];
-	fp = popen( sCommand.ascii() , "r");
-	if (fp == NULL)
+	/// @nate.com인 경우에는 @nate.com을 제거하고 MD5를 만듬.
+	if ( sID.right(9) == "@nate.com" )
 	{
-		KMessageBox::error( 0, strerror( errno) );
-		exit(0);
+		sID = sID.left( sID.length() -9 );
 	}
-	fgets(buff, MAXLINE, fp);
-	
-	int i, num = 0;
-	char a[2];
-	char out[33];
-	memset( out, 0x00, 33 );
-	for ( i = 0; i < 32; i++ )
-	{
-		memset( a, 0x00, 2 );
-		snprintf( a, 2,"%c", ( buff[(i*2)] ) );
-		num = atoi( a ) * 16;
-		memset( a, 0x00, 2 );
-		snprintf( a, 2,"%c", ( buff[(i*2) + 1] ) );
-		num += atoi( a );
-		
-		sprintf( out + i, "%c", num );
-	}
-	
-	using namespace AutoVersion;
-	
-	QString cmd;
-	cmd.sprintf( "%s MD5 %d.%d.%d.%d UTF8 ko.linux\r\n", \
-		out, \
-		MAJOR, MINOR, BUILD, REVISION );
-	sendCommand( "LSIN", m_pCurrentAccount->getID() + " " + cmd );
-	// sendCommand( "LSIN", m_pCurrentAccount->getID() + " " + out + " " + "MD5 3.871 UTF8 ko.linux\r\n" );
 
-	pclose( fp );
-#endif
+	KMD5 context (sOrgPasswd+sID.lower());
+
+	sendCommand( "LSIN", m_pCurrentAccount->getID() + " " + context.hexDigest().data() + " " + "MD5 3.871 UTF8\r\n" );
 }
 
 
@@ -447,7 +298,7 @@ void NateonDPConnection::gotLSIN(const QStringList& slCommand)
 	m_pCurrentAccount->setMyAuthYN( atoi(slCommand[9]) );
 	m_pCurrentAccount->setMyMIMID( slCommand[10] );
 	m_pCurrentAccount->setMyMusicDate( slCommand[11] );
-	m_pCurrentAccount->setMyLoginType( slCommand[12][0] ); /*! 네이트 아이디 : 'N', 싸이월드 아이디 : 'C' */
+	m_pCurrentAccount->setMyLoginType( slCommand[12][0] ); /*! 네이트닷컴아이디 : 'N', 싸이월드아이디 : 'C' */
 	m_pCurrentAccount->setMyNateCMN( slCommand[13] );
 	m_pCurrentAccount->setMyNateID( slCommand[14] );
 	m_pCurrentAccount->setMyCyworldID( slCommand[15] );
@@ -517,10 +368,8 @@ void NateonDPConnection::gotGLST(const QStringList& slCommand)
 	else if (7 == slCommand.size())
 	{
 		QStringList* tempStringList = pGroupList.find( slCommand[6] );
-		if ( tempStringList ) {
-			tempStringList->append( slCommand[5] );
-			pGroupList.replace( slCommand[6], tempStringList );
-		}
+		tempStringList->append( slCommand[5] );
+		pGroupList.replace( slCommand[6], tempStringList );
 	}
 	// if last group list item received
 	if  (slCommand.count() > 3 && (atoi(slCommand[2]) + 1 == atoi(slCommand[3])))
@@ -542,22 +391,9 @@ void NateonDPConnection::gotLIST(const QStringList& slCommand)
 #ifdef NETDEBUG
 	kdDebug() << "SLCOMMAND : " << slCommand << endl;
 #endif
-    
-    bool isAll = FALSE;
-    
-    if ( slCommand.count() > 2 ) {
-        int nCnt = atoi(slCommand[2]);
-        int nTot = atoi(slCommand[3]);
-        
-        if ( nTot == 0 ) { /*! 버디가 하나도 없을때 */
-            isAll = TRUE;
-        } else if ( ( nCnt + 1 ) == nTot ) {
-            isAll = TRUE;
-        }
-    }
-    
-	/*! 버디리스트를 모두 받았나? */ 
-	if  ( isAll )
+
+	// if last buddy list item received
+	if  ( (slCommand.count() > 2) && (atoi(slCommand[2]) + 1 == atoi(slCommand[3])))
 	{
 		Group* pGroup = NULL;
 		Buddy* pBuddy = NULL;
@@ -795,9 +631,8 @@ void NateonDPConnection::gotADSB(const QStringList & slCommand)
 {
 	if ( slCommand[2] == "REQST" )
 	{
-#if 0
 		emit receivedREQST( slCommand );
-#else
+#if 0
 		if ( slCommand[1] == "0" )
 		{
 			emit receivedREQST( slCommand );
